from .e621 import e621

__author__ = "PatriotRossii"
__version__ = "0.1.0"
__email__ = "patriotrosii2019@mail.ru"
